==> ocstore25_4_23.zip: OcStore/Prgm/data/CS_item.lua <==
----------------物品栏函数---------------
--[[
    物品栏的脚本是个没有初始化的子游戏-----
    要使用主游戏的脚本指令，得先SUB(true),
    调用了SUB指令后，指令目标就是主游戏
    记得要调回SUB(false)
--]]
function ItemLocked()
    TUR()MSG("\n该物品被其他玩家占用中")W99()
end

--珍鱼
function ItemSystem_Chinfish()
    TUR()MSG("*珍鱼*")W99()
end
function ItemSystem_Chinfish_Check()
    if(LOC()) then
        ItemLocked()
    else
        LOC(true)
        KEY()MSG("\n是咪咪卡村附近池塘里常见的小鱼。")NOD()CLR()
        CAT("\n要食用嘛？")YNJ()
        if(YES()) then
            SUB(true)
            --增加所有玩家的生命最大值1点
            MLP(1)IMM()
            ITS("Chinfish",1)
            SUB(false)
        end    
        LOC(false)
    end
end
RGI("Chinfish","CS_item_chinfish","ItemSystem_Chinfish","ItemSystem_Chinfish_Check",true)

--生命胶囊
function ItemSystem_LifeCapsule()
    TUR()MSG("*生命胶囊*")W99()
end
function ItemSystem_LifeCapsule_Check()
    MSG("\n使用后能够提高生命最大值。")NOD()W99()
end
RGI("LifeCapsule","CS_item_lifecapsule","ItemSystem_LifeCapsule","ItemSystem_LifeCapsule_Check",false)

--钉鞋
function ItemSystem_Spikes()
    TUR()MSG("*钉鞋*")W99()
end
function ItemSystem_Spikes_Check()
    MSG("钉鞋能够让移动更加敏捷")
    CAT("\n还能够在上方踩踏攻击敌人。")NOD()W99()
end
RGI("Spikes","CS_item_spikes","ItemSystem_Spikes","ItemSystem_Spikes_Check",false)

--地图系统
function ItemSystem_MapSystem()
    TUR()MSG("*地图系统*")W99()
end
function ItemSystem_MapSystem_Check()
    MAP()
end
RGI("MapSystem","CS_item_mapsystem","ItemSystem_MapSystem","ItemSystem_MapSystem_Check",false)

--青鱼
function ItemSystem_Bluefish()
    TUR()MSG("*青鱼*")W99()
end
function ItemSystem_Bluefish_Check()
    if(LOC()) then
        ItemLocked()
    else
        LOC(true)
        KEY()MSG("在野外的河流湖泊里居多")
        CAT("\n喜欢四处游动的小鱼。")NOD()CLR()
        CAT("\n要食用嘛？")YNJ()
        if(YES()) then
            SUB(true)
            --增加所有玩家的生命最大值2点
            MLP(2)IMM()
            ITS("Bluefish",1)
            SUB(false)
        end    
        LOC(false)
    end
end
RGI("Bluefish","CS_item_bluefish","ItemSystem_Bluefish","ItemSystem_Bluefish_Check",true)

--赤鱼
function ItemSystem_Redfish()
    TUR()MSG("*赤鱼*")W99()
end
function ItemSystem_Redfish_Check()
    if(LOC()) then
        ItemLocked()
    else
        LOC(true)
        KEY()MSG("赤鱼比较胆小，一有动静它们会立即逃走")
        CAT("\n平时躲在湖泊底部难以发现。")NOD()CLR()
        CAT("\n要食用嘛？")YNJ()
        if(YES()) then
            SUB(true)
            --增加所有玩家的生命最大值3点
            MLP(3)IMM()
            ITS("Redfish",1)
            SUB(false)
        end    
        LOC(false)
    end
end
RGI("Redfish","CS_item_redfish","ItemSystem_Redfish","ItemSystem_Redfish_Check",true)

--生锈的钥匙
function ItemSystem_RustKey()
    TUR()MSG("*生锈的钥匙*")W99()
end
function ItemSystem_RustKey_Check()
    MSG("\n在池塘里钓到的生锈钥匙...")NOD()W99()
end
RGI("RustKey","CS_item_rustkey","ItemSystem_RustKey","ItemSystem_RustKey_Check",true)

--龙鱼
function ItemSystem_Arowana()
    TUR()MSG("*龙鱼*")W99()
end
function ItemSystem_Arowana_Check()
    MSG("\n在洞窟内部钓到的难缠大鱼")NOD()W99()
end
RGI("Arowana","CS_item_arowana","ItemSystem_Arowana","ItemSystem_Arowana_Check",false)

--多隆子的项链
function ItemSystem_TorokoNecklace()
    TUR()MSG("*多隆子的项链*")W99()
end
function ItemSystem_TorokoNecklace_Check()
    MSG("\n是多隆子一直戴着的小鱼项链")NOD()W99()
end
RGI("TorokoNecklace","CS_item_torokonecklace","ItemSystem_TorokoNecklace","ItemSystem_TorokoNecklace_Check",false)

--翻译机
function ItemSystem_Translator()
    TUR()MSG("*翻译机*")W99()
end
function ItemSystem_Translator_Check()
    MSG("\n有这件物品就可以和人类进行交谈")NOD()W99()
end
RGI("Translator","CS_item_translator","ItemSystem_Translator","ItemSystem_Translator_Check",false)

--火球
function ItemSystem_Fireball()
    TUR()MSG("- 火球 -")W99()
end
function ItemSystem_Fireball_Check()
    TUR()MSG("- 火球 -")
    CAT("\n说明：在地面跳转。")
    CAT("\n在坡道上可以发挥出其威力。")NOD()W99()
end
RGI("Fireball","CS_item_fireball","ItemSystem_Fireball","ItemSystem_Fireball_Check",false)

--泡泡枪
function ItemSystem_Bubbler()
    TUR()MSG("- 泡泡枪 -")W99()
end
function ItemSystem_Bubbler_Check()
    TUR()MSG("- 泡泡枪 -")
    CAT("\n说明：从以前的集会场的暖炉中取得。")
    CAT("\n其好用程度因人而异。")NOD()W99()
end
RGI("Bubbler","CS_item_bubbler","ItemSystem_Bubbler","ItemSystem_Bubbler_Check",false)

--幽灵火球
function ItemSystem_GhostFire()
    SUB(true)
    local bFishState = FLJ("FishState");
    SUB(false)
    if(bFishState) then
        TUR()MSG("- 幽灵火球（在鱼的形态下无法使用） -")W99()
    else
        TUR()MSG("- 幽灵火球 -")W99()
    end
end
function ItemSystem_GhostFire_Check()
    SUB(true)
    local bFishState = FLJ("FishState");
    SUB(false)
    if(bFishState) then
        MSG("虽然你真的很想使用它，")
        CAT("\n但你现在没有可以用来")
        CAT("\n扣动扳机的手。")NOD()W99()
    else
        TUR()MSG("- 幽灵火球 -")
        CAT("\n说明：火球的进化形态。")
        CAT("\n在空中反弹吞噬敌人并分裂。")NOD()W99()
    end
end
RGI("GhostFire","CS_item_ghostfire","ItemSystem_GhostFire","ItemSystem_GhostFire_Check",false)

--捕获者
function ItemSystem_Catcher()
    SUB(true)
    local bFishState = FLJ("FishState");
    SUB(false)
    if(bFishState) then
        TUR()MSG("- 捕获者（在鱼的形态下无法使用） -")W99()
    else
        TUR()MSG("- 捕获者 -")W99()
    end
end
function ItemSystem_Catcher_Check()
    SUB(true)
    local bFishState = FLJ("FishState");
    SUB(false)
    if(bFishState) then
        MSG("虽然你真的很想使用它，")
        CAT("\n但你现在没有可以用来")
        CAT("\n扣动扳机的手。")NOD()W99()
    else
        TUR()MSG("- 捕获者 -")
        CAT("\n说明：泡泡枪的进化形态。")
        CAT("\n困住敌人将其拉到地面上无法动弹。")NOD()W99()
    end
end
RGI("Catcher","CS_item_catcher","ItemSystem_Catcher","ItemSystem_Catcher_Check",false)

--恶魔之花
function ItemSystem_DemonFlower()
    TUR()MSG("- 恶魔之花 -")W99()
end
function ItemSystem_DemonFlower_Check()
    MSG("\n里面似乎蕴藏着某种魔法力量。")NOD()W99()
end
RGI("DemonFlower","CS_item_demonflower","ItemSystem_DemonFlower","ItemSystem_DemonFlower_Check",false)

--蜂巢
function ItemSystem_Honeycomb()
    TUR()MSG("- 蜂巢块 -")W99()
end
function ItemSystem_Honeycomb_Check()
    MSG("从巨型蜂巢采来的一小部分，")NOD()
    CAT("\n里面看样子有不少蜂蜜。")NOD()
    W99()
end
RGI("Honeycomb","CS_item_honeycomb","ItemSystem_Honeycomb","ItemSystem_Honeycomb_Check",false)

--蜂蜜
function ItemSystem_Honey()
    TUR()MSG("- 蜂蜜 -")W99()
end
function ItemSystem_Honey_Check()
    MSG("\n一罐野生蜂蜜。")NOD()W99()
end
RGI("Honey","CS_item_honey","ItemSystem_Honey","ItemSystem_Honey_Check",false)

--甜甜圈
function ItemSystem_Doughnut()
    TUR()MSG("- 巨型蜂蜜甜甜圈 -")W99()
end
function ItemSystem_Doughnut_Check()
    MSG("\n好大，这一个感觉都可以吃一天了。")NOD()W99()
end
RGI("Doughnut","CS_item_doughnut","ItemSystem_Doughnut","ItemSystem_Doughnut_Check",false)

--萤火虫
function ItemSystem_Firefly()
    TUR()MSG("- 萤火虫 -")W99()
end
function ItemSystem_Firefly_Check()
    MSG("\n一种会发光的神奇虫子。")NOD()W99()
end
RGI("Firefly","CS_item_firefly","ItemSystem_Firefly","ItemSystem_Firefly_Check",true)

--米克
function ItemSystem_Mick()
    TUR()MSG("- 米克 -")W99()
end
function ItemSystem_Mick_Check()
    MSG("米克非常擅长搜寻，")NOD()
    CAT("\n如果带它来到了正确的路口")
    CAT("\n它会吠叫进行提示。")NOD()
    W99()
end
RGI("Mick","CS_item_puppy","ItemSystem_Mick","ItemSystem_Mick_Check",false)

--恰可的口红
function ItemSystem_ChakoLipstick()
    TUR()MSG("- 恰可的口红 -")W99()
end
function ItemSystem_ChakoLipstick_Check()
    MSG("\n这是恰可最重要的随身物品。")NOD()W99()
end
RGI("ChakoLipstick","CS_item_chakolipstick","ItemSystem_ChakoLipstick","ItemSystem_ChakoLipstick_Check",false)

--电容器
function ItemSystem_Capacitor()
    TUR()MSG("- 电容器 -")W99()
end
function ItemSystem_Capacitor_Check()
    MSG("每当成功防御敌人的攻击时，")NOD()
    CAT("\n恢复1点能量。")W99()
end
RGI("Capacitor","CS_item_capacitor","ItemSystem_Capacitor","ItemSystem_Capacitor_Check",false)

--鱼饲料
function ItemSystem_FishFeed()
    TUR()MSG("- 鱼饲料 -")W99()
end
function ItemSystem_FishFeed_Check()
    MSG("\n咪咪卡也许能够食用吧...")NOD()W99()
end
RGI("FishFeed","CS_item_fishfeed","ItemSystem_FishFeed","ItemSystem_FishFeed_Check",false)

--剑
function ItemSystem_Sword()
    TUR()MSG("- 剑 -")W99()
end
function ItemSystem_Sword_Check()
    TUR()MSG("- 剑 -")
    CAT("\n说明：给予单发的大伤害。")
    CAT("\n拥有三种攻击模式。")NOD()W99()
end
RGI("Sword","CS_item_sword","ItemSystem_Sword","ItemSystem_Sword_Check",false)

==> ocstore25_6_20.zip: OcStore/Prgm/data/CS_item.lua <==
----------------物品栏函数---------------
--[[
    物品栏的脚本是个没有初始化的子游戏-----
    要使用主游戏的脚本指令，得先SUB(true),
    调用了SUB指令后，指令目标就是主游戏
    记得要调回SUB(false)
--]]
function ItemLocked()
    TUR()MSG("\n该物品被其他玩家占用中")W99()
end

--珍鱼
function ItemSystem_Chinfish()
    TUR()MSG("*珍鱼*")W99()
end
function ItemSystem_Chinfish_Check()
    if(LOC()) then
        ItemLocked()
    else
        LOC(true)
        KEY()MSG("\n是咪咪卡村附近池塘里常见的小鱼。")NOD()CLR()
        CAT("\n要食用嘛？")YNJ()
        if(YES()) then
            SUB(true)
            --增加所有玩家的生命最大值1点
            MLP(1)IMM()
            ITS("Chinfish",1)
            SUB(false)
        end    
        LOC(false)
    end
end
RGI("Chinfish","CS_item_chinfish","ItemSystem_Chinfish","ItemSystem_Chinfish_Check",true)

--生命胶囊
function ItemSystem_LifeCapsule()
    TUR()MSG("*生命胶囊*")W99()
end
function ItemSystem_LifeCapsule_Check()
    MSG("\n使用后能够提高生命最大值。")NOD()W99()
end
RGI("LifeCapsule","CS_item_lifecapsule","ItemSystem_LifeCapsule","ItemSystem_LifeCapsule_Check",false)

--钉鞋
function ItemSystem_Spikes()
    TUR()MSG("*钉鞋*")W99()
end
function ItemSystem_Spikes_Check()
    MSG("钉鞋能够让移动更加敏捷")
    CAT("\n还能够在上方踩踏攻击敌人。")NOD()W99()
end
RGI("Spikes","CS_item_spikes","ItemSystem_Spikes","ItemSystem_Spikes_Check",false)

--地图系统
function ItemSystem_MapSystem()
    TUR()MSG("*地图系统*")W99()
end
function ItemSystem_MapSystem_Check()
    MAP()
end
RGI("MapSystem","CS_item_mapsystem","ItemSystem_MapSystem","ItemSystem_MapSystem_Check",false)

--青鱼
function ItemSystem_Bluefish()
    TUR()MSG("*青鱼*")W99()
end
function ItemSystem_Bluefish_Check()
    if(LOC()) then
        ItemLocked()
    else
        LOC(true)
        KEY()MSG("在野外的河流湖泊里居多")
        CAT("\n喜欢四处游动的小鱼。")NOD()CLR()
        CAT("\n要食用嘛？")YNJ()
        if(YES()) then
            SUB(true)
            --增加所有玩家的生命最大值2点
            MLP(2)IMM()
            ITS("Bluefish",1)
            SUB(false)
        end    
        LOC(false)
    end
end
RGI("Bluefish","CS_item_bluefish","ItemSystem_Bluefish","ItemSystem_Bluefish_Check",true)

--赤鱼
function ItemSystem_Redfish()
    TUR()MSG("*赤鱼*")W99()
end
function ItemSystem_Redfish_Check()
    if(LOC()) then
        ItemLocked()
    else
        LOC(true)
        if(GOP() == 1) then
            KEY()MSG("赤鱼比较胆小，一有动静它们会立即逃走")
            CAT("\n平时躲在湖泊底部难以发现。")NOD()CLR()
        else
            KEY()MSG("赤鱼比较胆小，")
            CAT("\n一有动静它们会立即逃走")
            CAT("\n平时躲在湖泊底部难以发现。")NOD()CLR()
        end
        CAT("\n要食用嘛？")YNJ()
        if(YES()) then
            SUB(true)
            --增加所有玩家的生命最大值3点
            MLP(3)IMM()
            ITS("Redfish",1)
            SUB(false)
        end    
        LOC(false)
    end
end
RGI("Redfish","CS_item_redfish","ItemSystem_Redfish","ItemSystem_Redfish_Check",true)

--生锈的钥匙
function ItemSystem_RustKey()
    TUR()MSG("*生锈的钥匙*")W99()
end
function ItemSystem_RustKey_Check()
    MSG("\n在池塘里钓到的生锈钥匙...")NOD()W99()
end
RGI("RustKey","CS_item_rustkey","ItemSystem_RustKey","ItemSystem_RustKey_Check",true)

--龙鱼
function ItemSystem_Arowana()
    TUR()MSG("*龙鱼*")W99()
end
function ItemSystem_Arowana_Check()
    MSG("\n在洞窟内部钓到的难缠大鱼。")NOD()W99()
end
RGI("Arowana","CS_item_arowana","ItemSystem_Arowana","ItemSystem_Arowana_Check",false)

--多隆子的项链
function ItemSystem_TorokoNecklace()
    TUR()MSG("*多隆子的项链*")W99()
end
function ItemSystem_TorokoNecklace_Check()
    MSG("\n是多隆子一直戴着的小鱼项链。")NOD()W99()
end
RGI("TorokoNecklace","CS_item_torokonecklace","ItemSystem_TorokoNecklace","ItemSystem_TorokoNecklace_Check",false)

--翻译机
function ItemSystem_Translator()
    TUR()MSG("*翻译机*")W99()
end
function ItemSystem_Translator_Check()
    MSG("\n有这件物品就可以和人类进行交谈。")NOD()W99()
end
RGI("Translator","CS_item_translator","ItemSystem_Translator","ItemSystem_Translator_Check",false)

--火球
function ItemSystem_Fireball()
    TUR()MSG("- 火球 -")W99()
end
function ItemSystem_Fireball_Check()
    TUR()MSG("- 火球 -")
    CAT("\n说明：在地面跳转。")
    CAT("\n在坡道上可以发挥出其威力。")NOD()W99()
end
RGI("Fireball","CS_item_fireball","ItemSystem_Fireball","ItemSystem_Fireball_Check",false)

--泡泡枪
function ItemSystem_Bubbler()
    TUR()MSG("- 泡泡枪 -")W99()
end
function ItemSystem_Bubbler_Check()
    TUR()
    if(GOP() == 1) then
        MSG("- 泡泡枪 -")
        CAT("\n说明：从以前的集会场的暖炉中取得。")
        CAT("\n其好用程度因人而异。")NOD()W99()
    else
        MSG("- 泡泡枪 -")
        CAT("\n说明：从以前的集会场")
        CAT("\n的暖炉中取得。")NOD()
        CAT("\n其好用程度因人而异。")NOD()W99()
    end
end
RGI("Bubbler","CS_item_bubbler","ItemSystem_Bubbler","ItemSystem_Bubbler_Check",false)

--幽灵火球
function ItemSystem_GhostFire()
    SUB(true)
    local bFishState = FLJ("FishState");
    SUB(false)
    if(bFishState) then
        if(GOP() == 1) then
            TUR()MSG("- 幽灵火球（在鱼的形态下无法使用） -")W99()
        else
            TUR()MSG("- 幽灵火球（在鱼的")
            CAT("\n形态下无法使用） -")W99()
        end
    else
        TUR()MSG("- 幽灵火球 -")W99()
    end
end
function ItemSystem_GhostFire_Check()
    SUB(true)
    local bFishState = FLJ("FishState");
    SUB(false)
    if(bFishState) then
        MSG("虽然你真的很想使用它，")
        CAT("\n但你现在没有可以用来")
        CAT("\n扣动扳机的手。")NOD()W99()
    else
        TUR()MSG("- 幽灵火球 -")
        CAT("\n说明：火球的进化形态。")
        CAT("\n在空中反弹吞噬敌人并分裂。")NOD()W99()
    end
end
RGI("GhostFire","CS_item_ghostfire","ItemSystem_GhostFire","ItemSystem_GhostFire_Check",false)

--捕获者
function ItemSystem_Catcher()
    SUB(true)
    local bFishState = FLJ("FishState");
    SUB(false)
    if(bFishState) then
        if(GOP() == 1) then
            TUR()MSG("- 捕获者（在鱼的形态下无法使用） -")W99()
        else
            TUR()MSG("- 捕获者（在鱼的")
            CAT("\n形态下无法使用） -")W99()
        end
    else
        TUR()MSG("- 捕获者 -")W99()
    end
end
function ItemSystem_Catcher_Check()
    SUB(true)
    local bFishState = FLJ("FishState");
    SUB(false)
    if(bFishState) then
        MSG("虽然你真的很想使用它，")
        CAT("\n但你现在没有可以用来")
        CAT("\n扣动扳机的手。")NOD()W99()
    else
        TUR()MSG("- 捕获者 -")
        CAT("\n说明：泡泡枪的进化形态。")
        CAT("\n困住敌人将其拉到地面上无法动弹。")NOD()W99()
    end
end
RGI("Catcher","CS_item_catcher","ItemSystem_Catcher","ItemSystem_Catcher_Check",false)

--恶魔之花
function ItemSystem_DemonFlower()
    TUR()MSG("- 恶魔之花 -")W99()
end
function ItemSystem_DemonFlower_Check()
    MSG("\n里面似乎蕴藏着某种魔法力量。")NOD()W99()
end
RGI("DemonFlower","CS_item_demonflower","ItemSystem_DemonFlower","ItemSystem_DemonFlower_Check",false)

--蜂巢
function ItemSystem_Honeycomb()
    TUR()MSG("- 蜂巢块 -")W99()
end
function ItemSystem_Honeycomb_Check()
    MSG("从巨型蜂巢采来的一小部分，")NOD()
    CAT("\n里面看样子有不少蜂蜜。")NOD()
    W99()
end
RGI("Honeycomb","CS_item_honeycomb","ItemSystem_Honeycomb","ItemSystem_Honeycomb_Check",false)

--蜂蜜
function ItemSystem_Honey()
    TUR()MSG("- 蜂蜜 -")W99()
end
function ItemSystem_Honey_Check()
    MSG("\n一罐野生蜂蜜。")NOD()W99()
end
RGI("Honey","CS_item_honey","ItemSystem_Honey","ItemSystem_Honey_Check",false)

--甜甜圈
function ItemSystem_Doughnut()
    TUR()MSG("- 巨型蜂蜜甜甜圈 -")W99()
end
function ItemSystem_Doughnut_Check()
    if(GOP() == 1) then
        MSG("\n好大，这一个感觉都可以吃一天了。")NOD()W99()
    else
        MSG("好大，这一个")
        CAT("\n感觉都可以吃一天了。")NOD()W99()
    end
end
RGI("Doughnut","CS_item_doughnut","ItemSystem_Doughnut","ItemSystem_Doughnut_Check",false)

--萤火虫
function ItemSystem_Firefly()
    TUR()MSG("- 萤火虫 -")W99()
end
function ItemSystem_Firefly_Check()
    MSG("\n一种会发光的神奇虫子。")NOD()W99()
end
RGI("Firefly","CS_item_firefly","ItemSystem_Firefly","ItemSystem_Firefly_Check",true)

--米克
function ItemSystem_Mick()
    TUR()MSG("- 米克 -")W99()
end
function ItemSystem_Mick_Check()
    MSG("米克非常擅长搜寻，")NOD()
    CAT("\n如果带它来到了正确的路口")
    CAT("\n它会吠叫进行提示。")NOD()
    W99()
end
RGI("Mick","CS_item_puppy","ItemSystem_Mick","ItemSystem_Mick_Check",false)

--恰可的口红
function ItemSystem_ChakoLipstick()
    TUR()MSG("- 恰可的口红 -")W99()
end
function ItemSystem_ChakoLipstick_Check()
    MSG("\n这是恰可最重要的随身物品。")NOD()W99()
end
RGI("ChakoLipstick","CS_item_chakolipstick","ItemSystem_ChakoLipstick","ItemSystem_ChakoLipstick_Check",false)

--电容器
function ItemSystem_Capacitor()
    TUR()MSG("- 电容器 -")W99()
end
function ItemSystem_Capacitor_Check()
    MSG("每当成功防御敌人的攻击时，")NOD()
    CAT("\n恢复1点能量。")W99()
end
RGI("Capacitor","CS_item_capacitor","ItemSystem_Capacitor","ItemSystem_Capacitor_Check",false)

--鱼饲料
function ItemSystem_FishFeed()
    TUR()MSG("- 鱼饲料 -")W99()
end
function ItemSystem_FishFeed_Check()
    MSG("\n咪咪卡也许能够食用吧...")NOD()W99()
end
RGI("FishFeed","CS_item_fishfeed","ItemSystem_FishFeed","ItemSystem_FishFeed_Check",false)

--剑
function ItemSystem_Sword()
    TUR()MSG("- 剑 -")W99()
end
function ItemSystem_Sword_Check()
    TUR()MSG("- 剑 -")
    CAT("\n说明：给予单发的大伤害。")
    CAT("\n拥有三种攻击模式。")NOD()W99()
end
RGI("Sword","CS_item_sword","ItemSystem_Sword","ItemSystem_Sword_Check",false)

--生命罐
function ItemSystem_LifePot()
    TUR()MSG("*生命罐*")W99()
end
function ItemSystem_LifePot_Check()
    if(LOC()) then
        ItemLocked()
    else
        LOC(true)
        KEY()MSG("可以回复生命点数一次。")
        CAT("\n要使用吗？")YNJ()
        if(YES()) then
            SUB(true)
            --恢复所有生命
            LIP(1000,PLY())IMM()
            ITS("LifePot",1)
            SUB(false)
        end    
        LOC(false)
    end
end
RGI("LifePot","CS_item_lifepot","ItemSystem_LifePot","ItemSystem_LifePot_Check",true)

--突波
function ItemSystem_Spur()
    TUR()MSG("- 突波 -")W99()
end
function ItemSystem_Spur_Check()
    TUR()MSG("- 突波 -")
    CAT("\n说明：按住按钮一段时间")
    CAT("\n可以发出雷射。")NOD()W99()
end
RGI("Spur","CS_item_spur","ItemSystem_Spur","ItemSystem_Spur_Check",false)

--超级飞弹
function ItemSystem_SuperMissile()
    TUR()MSG("- 超级飞弹 -")W99()
end
function ItemSystem_SuperMissile_Check()
    TUR()MSG("- 超级飞弹 -")
    CAT("\n说明：爽快系飞弹。")
    CAT("\n加速力非常优秀。")NOD()W99()
end
RGI("SuperMissile","CS_item_supermissile","ItemSystem_SuperMissile","ItemSystem_SuperMissile_Check",false)

--机枪
function ItemSystem_MachineGun()
    TUR()MSG("- 机枪 -")W99()
end
function ItemSystem_MachineGun_Check()
    TUR()MSG("- 机枪 -")
    CAT("\n说明：自动连射。")
    CAT("\n弹数随着时间自动回复。")NOD()W99()
end
RGI("MachineGun","CS_item_machinegun","ItemSystem_MachineGun","ItemSystem_MachineGun_Check",false)

--复仇女神
function ItemSystem_Nemesis()
    TUR()MSG("- 复仇女神 -")W99()
end
function ItemSystem_Nemesis_Check()
    TUR()MSG("- 复仇女神 -")
    CAT("\n说明：女神之雷。")
    CAT("\n永远保持在Level 1的最强形态。")NOD()W99()
end
RGI("Nemesis","CS_item_nemesis","ItemSystem_Nemesis","ItemSystem_Nemesis_Check",false)

--氧气瓶
function ItemSystem_AirTank()
    TUR()MSG("- 氧气瓶 -")W99()
end
function ItemSystem_AirTank_Check()
    TUR()MSG("\n可以在水中呼吸。")NOD()W99()
end
RGI("AirTank","CS_item_airtank","ItemSystem_AirTank","ItemSystem_AirTank_Check",false)

--电梯钥匙
function ItemSystem_LiftKey()
    TUR()MSG("- 电梯钥匙 -")W99()
end
function ItemSystem_LiftKey_Check()
    TUR()MSG("\n从MrG身上掉落的。")NOD()W99()
end
RGI("LiftKey","CS_item_liftkey","ItemSystem_LiftKey","ItemSystem_LiftKey_Check",false)

--牵引绳
function ItemSystem_TowRope()
    TUR()MSG("- 牵引绳 -")W99()
end
function ItemSystem_TowRope_Check()
    MSG("用它代替了鱼线")
    CAT("\n现在可以用鱼竿来向上攀爬了。")NOD()W99()
end
RGI("TowRope","CS_item_towrope","ItemSystem_TowRope","ItemSystem_TowRope_Check",false)

--铁门钥匙
function ItemSystem_IronKey()
    TUR()MSG("- 铁门钥匙 -")W99()
end
function ItemSystem_IronKey_Check()
    MSG("用它打开马宾的铁门")
    CAT("\n一起回家吧~")NOD()W99()
end
RGI("IronKey","CS_item_ironkey","ItemSystem_IronKey","ItemSystem_IronKey_Check",false)
